@@ -68,6 +68,7 @@ K3b::TempDirSelectionWidget::TempDirSelectionWidget( QWidget *parent )
     // choose a default
     setSelectionMode( DIR );
 
+    m_editDirectory->setAcceptMode(QFileDialog::AcceptSave);
     m_editDirectory->setUrl( QUrl::fromLocalFile( k3bcore->globalSettings()->defaultTempPath() ) );
     slotUpdateFreeTempSpace();
 
@@ -267,3 +268,7 @@ void K3b::TempDirSelectionWidget::fixTempPath( bool forceNewImageName )
 }
 
 
+void K3b::TempDirSelectionWidget::setImageFileLabel(const QString &label)
+{
+    m_imageFileLabel->setText(label);
+}
