@@ -16,7 +16,8 @@
 #include <KCoreAddons/KAboutData>
 #include <KI18n/KLocalizedString>
 #include <QtCore/QCommandLineParser>
-#ifdef __clang__
+#include <QIcon>
+#if defined(__clang__) && defined(LLVM_MAJOR) && (LLVM_MAJOR > 5)
 #include <sanitizer/common_interface_defs.h>
 #endif
 
@@ -102,6 +103,8 @@ int main( int argc, char* argv[] )
 
     KAboutData::setApplicationData( aboutData );
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("k3b"), app.windowIcon()));
+
     QCommandLineParser* parser = new QCommandLineParser;
     parser->addHelpOption();
     parser->addVersionOption();
@@ -135,11 +138,9 @@ int main( int argc, char* argv[] )
 
     app.init( parser );
 
-#ifdef __clang__
+#if defined(__clang__) && defined(LLVM_MAJOR) && (LLVM_MAJOR > 5)
     if (argc > 2)
-#if LLVM_MAJOR > 5
         __sanitizer_print_memory_profile(atoi(argv[1]), atoi(argv[2]));
-#endif
 #endif
 
     return app.exec();
